From 1c51dff18a6a9508bd11dd95f07be4dc4fb9c542 Mon Sep 17 00:00:00 2001
From: hli <hli@mdc-berlin.de>
Date: Mon, 22 Mar 2021 11:00:47 +0100
Subject: [PATCH] adding r-chromstardata and r-signac packages

---
 gnu/packages/statistics.scm | 127 ++++++++++++++++++++++++++++++++++++
 1 file changed, 127 insertions(+)

diff --git a/gnu/packages/statistics.scm b/gnu/packages/statistics.scm
index 27f3bfa8ef..0cf026fcfb 100644
--- a/gnu/packages/statistics.scm
+++ b/gnu/packages/statistics.scm
@@ -1035,6 +1035,65 @@ designed by Cynthia Brewer as described at http://colorbrewer2.org")
 solution for sending email, including attachments, from within R.")
     (license license:gpl2+)))
 
+(define-public r-signac
+  (let ((commit
+          "e0512d348adeda4a3f23a2e8f56d1fe09840e03c")
+        (revision "1"))
+    (package
+      (name "r-signac")
+      (version (git-version "1.1.1" revision commit))
+      (source
+        (origin
+          (method git-fetch)
+          (uri (git-reference
+                 (url "https://github.com/timoast/signac/")
+                 (commit commit)))
+          (file-name (git-file-name name version))
+          (sha256
+            (base32
+              "1yihhrv7zs87ax61la1nb4y12lg3knraw4b20k5digbcwm8488lb"))))
+      (properties `((upstream-name . "Signac")))
+      (build-system r-build-system)
+      (inputs `(("zlib" ,zlib)))
+      (propagated-inputs
+        `(("r-annotationfilter" ,r-annotationfilter)
+          ("r-biocgenerics" ,r-biocgenerics)
+          ("r-biostrings" ,r-biostrings)
+          ("r-biovizbase" ,r-biovizbase)
+          ("r-data-table" ,r-data-table)
+          ("r-dplyr" ,r-dplyr)
+          ("r-fastmatch" ,r-fastmatch)
+          ("r-future" ,r-future)
+          ("r-future-apply" ,r-future-apply)
+          ("r-genomeinfodb" ,r-genomeinfodb)
+          ("r-genomicranges" ,r-genomicranges)
+          ("r-ggbio" ,r-ggbio)
+          ("r-ggforce" ,r-ggforce)
+          ("r-ggplot2" ,r-ggplot2)
+          ("r-ggrepel" ,r-ggrepel)
+          ("r-ggseqlogo" ,r-ggseqlogo)
+          ("r-iranges" ,r-iranges)
+          ("r-irlba" ,r-irlba)
+          ("r-lsa" ,r-lsa)
+          ("r-matrix" ,r-matrix)
+          ("r-patchwork" ,r-patchwork)
+          ("r-pbapply" ,r-pbapply)
+          ("r-rcpp" ,r-rcpp)
+          ("r-rcpproll" ,r-rcpproll)
+          ("r-rsamtools" ,r-rsamtools)
+          ("r-s4vectors" ,r-s4vectors)
+          ("r-scales" ,r-scales)
+          ("r-seurat" ,r-seurat)
+          ("r-seuratobject" ,r-seuratobject)
+          ("r-stringi" ,r-stringi)
+          ("r-tidyr" ,r-tidyr)))
+      (home-page "https://github.com/timoast/signac/")
+      (synopsis
+        "Analysis of Single-Cell Chromatin Data")
+      (description
+        "This package provides a framework for the analysis and exploration of single-cell chromatin data.  The 'Signac' package contains functions for quantifying single-cell chromatin data, computing per-cell quality control metrics, dimension reduction and normalization, visualization, and DNA sequence motif analysis.  Reference: Stuart et al. (2020) <doi:10.1101/2020.11.09.373613>.")
+      (license expat))))
+
 (define-public r-stringi
   (package
     (name "r-stringi")
@@ -1851,6 +1910,74 @@ and density estimation.")
 times.")
     (license license:gpl2)))
 
+(define-public r-chromstardata
+  (package
+    (name "r-chromstardata")
+    (version "1.16.0")
+    (source
+      (origin
+        (method url-fetch)
+        (uri (bioconductor-uri
+               "chromstaRData"
+               version
+               'experiment))
+        (sha256
+          (base32
+            "0ph80d53598635bb8g61acg5rqwnj8644a0gh297r4hgbvwlflab"))))
+    (properties `((upstream-name . "chromstaRData")))
+    (build-system r-build-system)
+    (home-page
+      "https://bioconductor.org/packages/chromstaRData")
+    (synopsis
+      "ChIP-seq data for Demonstration Purposes")
+    (description
+      "ChIP-seq data for demonstration purposes in the chromstaR package.")
+    (license gpl3)))
+
+(define-public r-chromstar
+  (let ((commit
+          "16c0394a3a0857a050237d2b8b33cd02d92d6239")
+        (revision "1"))
+    (package
+      (name "r-chromstar")
+      (version (git-version "1.17.0" revision commit))
+      (source
+        (origin
+          (method git-fetch)
+          (uri (git-reference
+                 (url "https://git.bioconductor.org/packages/chromstaR")
+                 (commit commit)))
+          (file-name (git-file-name name version))
+          (sha256
+            (base32
+              "0wr6wlz3z3x21c25hgczalswicrqfhw00wmsa9jjd42w4hj5lkh9"))))
+      (properties `((upstream-name . "chromstaR")))
+      (build-system r-build-system)
+      (propagated-inputs
+        `(("r-bamsignals" ,r-bamsignals)
+          ("r-biocgenerics" ,r-biocgenerics)
+          ("r-chromstardata" ,r-chromstardata)
+          ("r-doparallel" ,r-doparallel)
+          ("r-foreach" ,r-foreach)
+          ("r-genomeinfodb" ,r-genomeinfodb)
+          ("r-genomicalignments" ,r-genomicalignments)
+          ("r-genomicranges" ,r-genomicranges)
+          ("r-ggplot2" ,r-ggplot2)
+          ("r-iranges" ,r-iranges)
+          ("r-mvtnorm" ,r-mvtnorm)
+          ("r-reshape2" ,r-reshape2)
+          ("r-rsamtools" ,r-rsamtools)
+          ("r-s4vectors" ,r-s4vectors)))
+      (native-inputs `(("r-knitr" ,r-knitr)))
+      (home-page
+        "https://git.bioconductor.org/packages/chromstaR")
+      (synopsis
+        "Combinatorial and Differential Chromatin State Analysis for ChIP-Seq Data")
+      (description
+        "This package implements functions for combinatorial and differential analysis of ChIP-seq data.  It includes uni- and multivariate peak-calling, export to genome browser viewable files, and functi
+ons for enrichment analyses.")
+      (license artistic2.0))))
+
 (define-public r-data-table
   (package
     (name "r-data-table")
-- 
2.17.1

